Module beamlit.models.policy
============================

Classes
-------

`Policy(metadata: beamlit.types.Unset | ForwardRef('Metadata') = <beamlit.types.Unset object>, spec: beamlit.types.Unset | ForwardRef('PolicySpec') = <beamlit.types.Unset object>)`
:   Rule that controls how a deployment is made and served (e.g. location restrictions)
    
    Attributes:
        metadata (Union[Unset, Metadata]): Metadata
        spec (Union[Unset, PolicySpec]): Policy specification
    
    Method generated by attrs for class Policy.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `metadata`
    :

    `spec`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :